Data documentation compiled by Great Expectations

### random

### default

Data Asset | Profiling Results | Expectation Suite
--- | --- | ---
f1 | BasicDatasetProfiler-ProfilingResults | BasicDatasetProfiler
f2 | BasicDatasetProfiler-ProfilingResults | BasicDatasetProfiler

### titanic

### default

Data Asset | Profiling Results | Expectation Suite
--- | --- | ---
Titanic | BasicDatasetProfiler-ProfilingResults | BasicDatasetProfiler

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.